@@ -13,8 +13,6 @@
 # here put the import lib
 import re
 import os
-import io
-import shutil
 import time
 # from Crypto.Cipher import AES 解密后CKPLAYER播放有问题.
 from decimal import *
